import edge.com.fs as fs
import edge.path_helpers as ph
from edge import eventlog
import os


def _get_limits_jnode(ui_jnode):
    """
    :type ui_jnode: dict
    :rtype: dict
    """
    ro_jnode = ui_jnode.get('ro')

    crt_file = ro_jnode.get('crt') or False
    key_file = ro_jnode.get('key') or False

    if crt_file and key_file:
        return {'activatable': True}

    return {'activatable': False}


def get():
    """
    :rtype: dict | None
    """
    if not os.path.exists(ph.SIGN_CONF_FILEPATH):
        fs.create_jnode_from_default(ph.SIGN_DEFAULT_CONF_FILEPATH, ph.SIGN_CONF_FILEPATH)
    sign_jnode = fs.load_json(ph.SIGN_CONF_FILEPATH)
    if sign_jnode:
        reply_jnode = sign_jnode.get('rw')
        reply_jnode['limits'] = _get_limits_jnode(sign_jnode)
        return reply_jnode

    return None


def put(body):
    """
    :type body: dict
    :rtype: dict | None
    """
    sign_jnode = fs.load_json(ph.SIGN_CONF_FILEPATH)
    if sign_jnode is None:
        eventlog.log_e('fail: open ')
        return None

    reply_jnode = sign_jnode.get('rw')
    reply_jnode['args']['active'] = body['args']['active']

    private_key_pass = body['args'].get('key-pass')
    if private_key_pass is not None:
        sign_jnode['ro']['key-sign-pass'] = private_key_pass

    fs.write_json_file(sign_jnode, ph.SIGN_CONF_FILEPATH, True)

    reply_jnode['limits'] = _get_limits_jnode(sign_jnode)
    return reply_jnode


def put_key(key_filepath):
    """
    :type key_filepath: str
    :rtype: dict | None
    """

    eventlog.log_d('try put key %s' % key_filepath)
    sign_jnode = fs.load_json(ph.SIGN_CONF_FILEPATH)
    if sign_jnode is None:
        eventlog.log_e('fail: open ')
        return

    fs.silent_link(key_filepath, ph.SIGN_KEY_FILEPATH)
    rw_jnode = sign_jnode.get('rw')
    ro_jnode = sign_jnode.get('ro')

    ro_jnode['key'] = True
    fs.write_json_file(sign_jnode, ph.SIGN_CONF_FILEPATH, True)

    rw_jnode['limits'] = _get_limits_jnode(sign_jnode)
    return rw_jnode


def put_crt(crt_filepath):
    """
    :type crt_filepath: str
    :rtype: dict | None
    """

    eventlog.log_d('try put sert %s' % crt_filepath)

    sign_jnode = fs.load_json(ph.SIGN_CONF_FILEPATH)
    if sign_jnode is None:
        eventlog.log_e('fail: open ')
        return

    fs.silent_link(crt_filepath, ph.SIGN_CRT_FILEPATH)

    ro_jnode = sign_jnode.get('ro')
    rw_jnode = sign_jnode.get('rw')

    ro_jnode['crt'] = True
    fs.write_json_file(sign_jnode, ph.SIGN_CONF_FILEPATH, True)

    rw_jnode['limits'] = _get_limits_jnode(sign_jnode)
    return rw_jnode
