#!/usr/bin/python
import os
import ujson
import sys

from edge import eventlog
from edge.admin.reply_helpers import *
import edge.admin.ui_types as ui_types
from edge.com.fs import ln_schema2


UI_TIMETZ_JNODE_FILEPATH = '/etc/edge/setupstore/admin/actions/time-tz.json'
UI_TIMETZ_DEFJNODE_FILEPATH = '/opt/edge/share/setupstore/ui/time-tz-jnode.json'


def _run(query_args):
    """
    :type query_args: ui_types.UiQueryArgs
    :rtype: dict
    """
    if query_args.http_method == 'GET':

        # create ui-jnode
        if not os.path.exists(UI_TIMETZ_JNODE_FILEPATH):
            # noinspection PyBroadException
            try:
                ln_schema2(UI_TIMETZ_JNODE_FILEPATH, UI_TIMETZ_DEFJNODE_FILEPATH)

            except Exception:
                eventlog.log_x()
                return reply_fail(REPLY_INTERNAL_SERVER_ERROR_500)

        with open(UI_TIMETZ_JNODE_FILEPATH, 'r') as json_file:
            ui_timetz_jnode = ujson.load(json_file)
        if not ui_timetz_jnode:
            raise ValueError("fail: load tz-jnode")

        reply_jnode = reply_done(ui_timetz_jnode)

    else:
        eventlog.log_d('fail: method (%s) not allowed' % query_args.http_method)
        reply_jnode = reply_fail(REPLY_METHOD_NOT_ALLOWED_405)

    return reply_jnode


def _main():
    eventlog.open_log('cgi-time-tz', 'debug')
    exit_code = 1
    # noinspection PyBroadException
    try:
        query_args = ui_types.UiQueryArgs.deserialize()

        if query_args.query_string or query_args.raw_body:
            response_dict = reply_fail(REPLY_BAD_REQUEST_400)
        elif query_args.path_info:
            response_dict = reply_fail(REPLY_NOT_FOUND_404)
        else:
            response_dict = _run(query_args)
        print ujson.dumps(dict(response_dict))
        exit_code = 0

    except Exception:
        eventlog.log_x()
    finally:
        eventlog.close_log()

    sys.exit(exit_code)


if __name__ == '__main__':
    _main()
